@@ -35,11 +35,11 @@ class Pathable(object):
         return self.get(path, params=params)
 
     # people
-    def create_person(self, data):
+    def create_person(self, body):
         """Create a person in Pathable API."""
         path = "people"
         url = f"{self.base_url}/{path}"
-        response = requests.post(url, headers=self.headers, data=data)
+        response = requests.post(url, headers=self.headers, json=body)
         response.raise_for_status()
         return response.json()
 
@@ -69,6 +69,15 @@ class Pathable(object):
         if results:
             return results[0]
 
+    # profiles
+    def create_profile(self, body):
+        """Create a profile in a pathable event."""
+        path = "people/profiles"
+        url = f"{self.base_url}/{path}"
+        response = requests.post(url, headers=self.headers, json=body)
+        response.raise_for_status()
+        return response.json()
+
     def get_profiles(self):
         """Return a list of profiles."""
         path = "people/profiles"
